pub struct ReferralWithExp {
pub user: User,
pub character: Character,
pub experience: i64,
}Fields
user: Usercharacter: Characterexperience: i64Trait Implementations
Sourceimpl Clone for ReferralWithExp
impl Clone for ReferralWithExp
Sourcefn clone(&self) -> ReferralWithExp
fn clone(&self) -> ReferralWithExp
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReferralWithExp
impl Debug for ReferralWithExp
Sourceimpl<'de> Deserialize<'de> for ReferralWithExp
impl<'de> Deserialize<'de> for ReferralWithExp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ReferralWithExp> for JsValuewhere
ReferralWithExp: Serialize,
impl From<ReferralWithExp> for JsValuewhere
ReferralWithExp: Serialize,
Sourcefn from(value: ReferralWithExp) -> Self
fn from(value: ReferralWithExp) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ReferralWithExpwhere
Self: DeserializeOwned,
impl FromWasmAbi for ReferralWithExpwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for ReferralWithExpwhere
ReferralWithExp: Serialize,
impl IntoWasmAbi for ReferralWithExpwhere
ReferralWithExp: Serialize,
Sourceimpl JsonSchema for ReferralWithExp
impl JsonSchema for ReferralWithExp
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ReferralWithExpwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ReferralWithExpwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ReferralWithExpwhere
ReferralWithExp: Serialize,
impl OptionIntoWasmAbi for ReferralWithExpwhere
ReferralWithExp: Serialize,
Sourceimpl PartialEq for ReferralWithExp
impl PartialEq for ReferralWithExp
Sourceimpl RefFromWasmAbi for ReferralWithExpwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ReferralWithExpwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ReferralWithExp>
type Anchor = SelfOwner<ReferralWithExp>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ReferralWithExp
impl Serialize for ReferralWithExp
Sourceimpl Tsify for ReferralWithExp
impl Tsify for ReferralWithExp
const DECL: &'static str = "export interface ReferralWithExp {\n user: User;\n character: Character;\n experience: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ReferralWithExpwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ReferralWithExpwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ReferralWithExpwhere
ReferralWithExp: Serialize,
impl VectorIntoWasmAbi for ReferralWithExpwhere
ReferralWithExp: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for ReferralWithExp
impl WasmDescribeVector for ReferralWithExp
impl Eq for ReferralWithExp
impl StructuralPartialEq for ReferralWithExp